@@ -2,4 +2,4 @@
 #' @useDynLib BayesfMRI, .registration = TRUE
 #' @importFrom Rcpp evalCpp
 ## usethis namespace: end
-NULL
+"_PACKAGE"
